%global git_revision eab5c13
%global date 20141027
%define rel 38

%bcond_with evolution

Name:           mail-notification
Version:        5.4
Release:        %mkrel %{rel}.%{date}.git.%{git_revision}
Summary:        Status icon that informs you if you have new mail

Group:          Networking/Mail
License:        GPLv3+
URL:            https://www.nongnu.org/mailnotify/
#Source0:        https://savannah.nongnu.org/download/mailnotify/mail-notification-%{version}.tar.bz2
# Upstream isn't alive any more, use a github forked copy which contains all patches which
# have been collected over the past years: https://github.com/epienbroek/mail-notification
#
# To regenerate source tarball:
# wget https://github.com/epienbroek/mail-notification/tarball/$git_revision -O mail-notification-$git_revision.tar.gz
Source0:        mail-notification-%{git_revision}.tar.gz
# jb build system is turning on -Werror to build itself.  This patch fixes a
# warning with current gcc
Patch0: mail-notification-jb-gcc-format.patch

# Support aarch64
# https://bugzilla.redhat.com/show_bug.cgi?id=926114
Patch1:         mail-notification-aarch64.patch

# build break when building with evolution 3.11.2
Patch2:         mail-notification-evo3_11_2.patch

# Fix FTBFS against latest glibc
Patch3:         mail-notification-dont-link-against-bsd-compat.patch

BuildRequires:  gettext
BuildRequires:  desktop-file-utils, scrollkeeper
BuildRequires:  openssl-devel >= 0.9.6
BuildRequires:  pkgconfig(libsasl2) >= 2.0
BuildRequires:  glib2-devel >= 2.14
BuildRequires:  gtk3-devel
BuildRequires:  pkgconfig(gconf-2.0)
BuildRequires:  pkgconfig(libgnome-2.0)
BuildRequires:  dbus-glib-devel
BuildRequires:  libnotify-devel >= 0.4.1
BuildRequires:  gmime2.6-devel >= 2.4
BuildRequires:  libgnome-keyring-devel
BuildRequires:  perl-XML-Parser
BuildRequires:  gob2 >= 2.0.17
%if %{with evolution}
BuildRequires:  evolution-devel
BuildRequires:  evolution-data-server-devel >= 1.5
%endif

# needed for the gtk-builder-convert tool
BuildRequires:  gtk2-devel

# needed for the GConf RPM macros
BuildRequires:  GConf2

Requires:         hicolor-icon-theme

Requires(pre):    GConf2
Requires(post):   GConf2, scrollkeeper
Requires(preun):  GConf2
Requires(postun): scrollkeeper


%description
Mail Notification is a status icon (aka tray icon) that informs you if you
have new mail. It works with system trays implementing the freedesktop.org
System Tray Specification, such as the GNOME Panel Notification Area, the
Xfce Notification Area and the KDE System Tray.


%if %{with evolution}
%package        evolution-plugin
Summary:        Evolution plugin for Mail Notification
Group:          Networking/Mail
Requires:       %{name} = %{version}-%{release}

%description	evolution-plugin
Evolution support for Mail Notification.
%endif


%prep
%setup -q -n epienbroek-%{name}-%{git_revision}

%patch0 -p1
%patch1 -p1
%patch2 -p1 -b .evo3_11_2
%patch3 -p0


%build
# Temporary build without any optimalisations so we
# can get better stacktraces for RHBZ #531088
CFLAGS=$(echo $RPM_OPT_FLAGS | sed s/O2/O0/)

jb_cflags="$RPM_OPT_FLAGS" jb_ldflags="$RPM_LD_FLAGS" \
./jb configure \
  cc="%{__cc}" \
  cflags="$CFLAGS" \
  cppflags="-D_GNU_SOURCE" \
  ldflags="$RPM_LD_FLAGS" \
  destdir=$RPM_BUILD_ROOT \
  prefix=%{_prefix} \
  bindir=%{_bindir} \
  libdir=%{_libdir} \
  libexecdir=%{_libexecdir} \
  datadir=%{_datadir} \
  sysconfdir=%{_sysconfdir} \
  localstatedir=%{_localstatedir} \
  install-gconf-schemas=no

./jb build

# The build command above hides away all gcc commands and their warnings
# As they can be interesting show the build log manually
cat build/build.log


%install
# For GConf apps: prevent schemas from being installed at this stage
export GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL=1

./jb install

#  clear /var/lib/scrollkeeper stuff here
rm -rf $RPM_BUILD_ROOT%{_localstatedir}

find $RPM_BUILD_ROOT -type f -name "*.la" -exec rm -f {} ';'

%if %{with evolution}
chmod +x $RPM_BUILD_ROOT%{_libdir}/evolution/plugins/*.so
%endif

desktop-file-install \
  --dir ${RPM_BUILD_ROOT}%{_datadir}/gnome/autostart/  \
  --delete-original                                    \
  ${RPM_BUILD_ROOT}%{_sysconfdir}/xdg/autostart/mail-notification.desktop

desktop-file-install \
  --dir ${RPM_BUILD_ROOT}%{_datadir}/applications      \
  --delete-original                                    \
  --add-category X-GNOME-NetworkSettings               \
  ${RPM_BUILD_ROOT}%{_datadir}/applications/mail-notification-properties.desktop

%find_lang %{name}

%post
/usr/bin/scrollkeeper-update -q -o %{_datadir}/omf/%{name} || :

touch --no-create %{_datadir}/icons/hicolor || :
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :


%preun
%preun_uninstall_gconf_schemas %{name}


%postun
/usr/bin/scrollkeeper-update -q ||:

touch --no-create %{_datadir}/icons/hicolor || :
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :


%files -f %{name}.lang
%doc AUTHORS COPYING NEWS README TODO
%{_sysconfdir}/gconf/schemas/mail-notification.schemas
%{_bindir}/*
%{_datadir}/%{name}
%{_datadir}/gnome/autostart/*mail-notification.desktop
%{_datadir}/applications/*mail-notification-properties.desktop
%{_datadir}/gnome/help/mail-notification/
%dir %{_datadir}/omf/mail-notification/
%{_datadir}/omf/mail-notification/mail-notification-C.omf
%{_datadir}/icons/hicolor/*/apps/mail-notification.*


%if %{with evolution}
%files evolution-plugin
%{_libdir}/evolution/plugins/*
%endif


%changelog
* Wed Apr 06 2022 umeabot <umeabot> 5.4-38.20141027.git.eab5c13.mga9
+ Revision: 1845853
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 5.4-37.20141027.git.eab5c13.mga9
+ Revision: 1747884
- rebuild for openssl 3.0.0

* Fri Sep 17 2021 joequant <joequant> 5.4-36.20141027.git.eab5c13.mga9
+ Revision: 1745626
- rebuild
+ wally <wally>
- build with our %%ldflags

* Thu Feb 13 2020 umeabot <umeabot> 5.4-35.20141027.git.eab5c13.mga8
+ Revision: 1515115
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 5.4-34.20141027.git.eab5c13.mga7
+ Revision: 1299440
- Mageia 7 Mass Rebuild

* Mon Dec 18 2017 wally <wally> 5.4-33.20141027.git.eab5c13.mga7
+ Revision: 1183242
- build with gmime2.6

* Fri Sep 08 2017 cjw <cjw> 5.4-32.20141027.git.eab5c13.mga7
+ Revision: 1151976
- rebuild for openssl 1.1

* Tue Mar 08 2016 blino <blino> 5.4-31.20141027.git.eab5c13.mga6
+ Revision: 987257
- make the spec mass-rebuild-friendly

* Mon Oct 27 2014 joequant <joequant> 5.4-30.20141027.git.eab5c13.mga6
+ Revision: 793861
- imported package mail-notification


* Fri Dec 10 2010 Götz Waschk <waschk@mandriva.org> 5.4-15mdv2011.0
+ Revision: 620433
- update missing icons patch (Joseph Wang

* Wed Dec 08 2010 Götz Waschk <waschk@mandriva.org> 5.4-14mdv2011.0
+ Revision: 616265
- update evolution patches

* Thu Aug 05 2010 Götz Waschk <waschk@mandriva.org> 5.4-13mdv2011.0
+ Revision: 566226
- fix build with new evolution-data-server

* Fri Apr 16 2010 Frederic Crozat <fcrozat@mandriva.com> 5.4-12mdv2010.1
+ Revision: 535420
- Fix build
- Patch3: do not use deprecated stock icons

* Mon Feb 01 2010 Götz Waschk <waschk@mandriva.org> 5.4-11mdv2010.1
+ Revision: 499242
- update build deps
- update Evolution patch from Fedora
- fix off-by-one error in SASL auth
- fix line numbers for debugging

  + Frederic Crozat <fcrozat@mandriva.com>
    - Suggests fetchyahoo for Yahoo Mail support

* Mon May 11 2009 Götz Waschk <waschk@mandriva.org> 5.4-9mdv2010.0
+ Revision: 374590
- rebuild for new evolution

* Sun May 03 2009 Götz Waschk <waschk@mandriva.org> 5.4-8mdv2010.0
+ Revision: 371118
- patch for new gmime

* Mon Feb 02 2009 Götz Waschk <waschk@mandriva.org> 5.4-7mdv2009.1
+ Revision: 336622
- rebuild

* Mon Nov 03 2008 Götz Waschk <waschk@mandriva.org> 5.4-6mdv2009.1
+ Revision: 299519
- rebuild for new evolution

* Mon Oct 20 2008 Götz Waschk <waschk@mandriva.org> 5.4-5mdv2009.1
+ Revision: 295655
- rebuild for new evolution-data-server

* Tue Aug 12 2008 Götz Waschk <waschk@mandriva.org> 5.4-4mdv2009.0
+ Revision: 271216
- patch for new evolution
- fix optflags
- disable --no-undefined

* Tue Jul 22 2008 Götz Waschk <waschk@mandriva.org> 5.4-3mdv2009.0
+ Revision: 240201
- rebuild

* Fri Jul 04 2008 Götz Waschk <waschk@mandriva.org> 5.4-2mdv2009.0
+ Revision: 231592
- update license
- rebuild for new nautilus

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Thu May 22 2008 Götz Waschk <waschk@mandriva.org> 5.4-1mdv2009.0
+ Revision: 210120
- new version
- new version

* Tue Mar 25 2008 Götz Waschk <waschk@mandriva.org> 5.2-1mdv2008.1
+ Revision: 189825
- new version

* Fri Mar 21 2008 Götz Waschk <waschk@mandriva.org> 5.1-1mdv2008.1
+ Revision: 189359
- new version
- drop patch
- update file list
- fix build deps
- adapt for new build system (what a great idea, everyone tries to
- replace the GNU autotools)

* Fri Feb 01 2008 Götz Waschk <waschk@mandriva.org> 5.0-1mdv2008.1
+ Revision: 161044
- new version
- fix build with new eel
- update buildrequires

  + Thierry Vignaud <tv@mandriva.org>
    - drop old menu
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Nov 27 2007 Götz Waschk <waschk@mandriva.org> 5.0-0.rc1.1mdv2008.1
+ Revision: 113488
- new version
- drop patch

* Mon Oct 29 2007 Götz Waschk <waschk@mandriva.org> 4.1-2mdv2008.1
+ Revision: 103047
- update the patch to fix build with evolution 2.12.1
- fix intltool build

* Tue Jun 26 2007 Götz Waschk <waschk@mandriva.org> 4.1-1mdv2008.0
+ Revision: 44509
- fix buildrequires
- new version
- update the patch

* Fri Jun 08 2007 Götz Waschk <waschk@mandriva.org> 4.0-2mdv2008.0
+ Revision: 37208
- rename evolution plugin

* Thu Jun 07 2007 Götz Waschk <waschk@mandriva.org> 4.0-1mdv2008.0
+ Revision: 36896
- patch for new evolution


* Wed Jan 17 2007 Götz Waschk <waschk@mandriva.org> 4.0-1mdv2007.0
+ Revision: 109952
- new version
- glib rebuild

* Tue Dec 19 2006 Götz Waschk <waschk@mandriva.org> 4.0-0.rc2.2mdv2007.1
+ Revision: 99537
- rebuild for new e-d-s

* Thu Dec 07 2006 Götz Waschk <waschk@mandriva.org> 4.0-0.rc2.1mdv2007.1
+ Revision: 92084
- new version

* Thu Nov 30 2006 Götz Waschk <waschk@mandriva.org> 4.0-0.rc1.4mdv2007.1
+ Revision: 88871
- rebuild to get the right evolution plugin dir

* Tue Nov 28 2006 Götz Waschk <waschk@mandriva.org> 4.0-0.rc1.3mdv2007.1
+ Revision: 87970
- add buildrequires for x86_64
- bot rebuild
- new version
- fix buildrequires
- handle new icons
- Import mail-notification

* Fri Aug 04 2006 Frederic Crozat <fcrozat@mandriva.com> 3.0-.0
- Rebuild with latest dbus

* Wed Aug 02 2006 Götz Waschk <waschk@mandriva.org> 3.0-4mdv2007.0
- fix error in postun

* Wed Aug 02 2006 Götz Waschk <waschk@mandriva.org> 3.0-3mdv2007.0
- xdg menu

* Fri Jul 14 2006 Frederic Crozat <fcrozat@mandriva.com> 3.0-2mdv2007.0
- Rebuild with latest libgail
- use macros

* Thu Jun 15 2006 Götz Waschk <waschk@mandriva.org> 3.0-1mdv2007.0
- new version

* Wed Jun 07 2006 Götz Waschk <waschk@mandriva.org> 3.0-0.rc2.2mdv2007.0
- rebuild for new evolution

* Fri May 19 2006 Götz Waschk <waschk@mandriva.org> 3.0-0.rc2.1mdk
- new version

* Wed May 17 2006 Götz Waschk <waschk@mandriva.org> 3.0-0.rc1.1mdk
- update deps
- update file list
- drop patches
- new version

* Sat Apr 22 2006 Nicolas Lécureuil <neoclust@mandriva.org> 2.0-11mdk
- Add BuildRequires: Mono-devel

* Fri Apr 21 2006 Götz Waschk <waschk@mandriva.org> 2.0-10mdk
- fix deps
- build with e-d-s 1.6.1

* Wed Feb 22 2006 Götz Waschk <waschk@mandriva.org> 2.0-9mdk
- fix buildrequires

* Wed Feb 22 2006 Götz Waschk <waschk@mandriva.org> 2.0-8mdk
- official patch for imap authentication problem

* Sun Nov 20 2005 Götz Waschk <waschk@mandriva.org> 2.0-7mdk
- rebuild for new openssl

* Thu Oct 13 2005 Götz Waschk <waschk@mandriva.org> 2.0-6mdk
- arrgh!

* Thu Oct 13 2005 Götz Waschk <waschk@mandriva.org> 2.0-5mdk
- trying to fix bug #19161

* Sat Oct 08 2005 Götz Waschk <waschk@mandriva.org> 2.0-4mdk
- evo 2.4

* Mon Aug 15 2005 Götz Waschk <waschk@mandriva.org> 2.0-3mdk
- enable evolution support

* Mon Aug 15 2005 Götz Waschk <waschk@mandriva.org> 2.0-2mdk
- register scrollkeeper files
- add menu entry
- patch for gmail

* Thu Aug 11 2005 Götz Waschk <waschk@mandriva.org> 2.0-1mdk
- fix file list
- small build patch
- New release 2.0

* Mon Mar 07 2005 Lenny Cartier <lenny@mandrakesoft.com> 1.1-1mdk
- 1.1

* Thu Nov 25 2004 Goetz Waschk <waschk@linux-mandrake.com> 1.0-1mdk
- New release 1.0

* Mon Nov 15 2004 Götz Waschk <waschk@linux-mandrake.com> 0.99-1mdk
- fix buildrequires
- New release 0.99

* Thu Nov 04 2004 Lenny Cartier <lenny@mandrakesoft.com> 0.8.1-1mdk
- 0.8.1

* Mon Nov 01 2004 Goetz Waschk <waschk@linux-mandrake.com> 0.8.0-1mdk
- New release 0.8.0

* Tue Oct 26 2004 Goetz Waschk <waschk@linux-mandrake.com> 0.7.1-1mdk
- New release 0.7.1

* Fri Oct 08 2004 Götz Waschk <waschk@linux-mandrake.com> 0.7.0-1mdk
- update file list
- build with soup
- source URL
- New release 0.7.0

* Wed Oct 06 2004 Götz Waschk <waschk@linux-mandrake.com> 0.6.2-3mdk
- fix buildrequires

* Thu Sep 30 2004 Götz Waschk <waschk@linux-mandrake.com> 0.6.2-2mdk
- fix buildrequires

* Mon Sep 13 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.6.2-1mdk
- Release 0.6.2
- Fix gconf schema install
- Remove pacth0 (merged upstream)

* Sat Aug 21 2004 Lenny Cartier <lenny@mandrakesoft.com> 0.6.1-0.2mdk
- add patch0 for ia64, ppc & x86_64

* Sat Aug 21 2004 Lenny Cartier <lenny@mandrakesoft.com> 0.6.1-0.1mdk
- new, please test
- no Gmail support without libsoup-1x

